@@ -1,5 +1,5 @@
 # ytcc - The YouTube channel checker
-# Copyright (C) 2019  Wolfgang Popp
+# Copyright (C) 2010  Wolfgang Popp
 #
 # This file is part of ytcc.
 #
@@ -23,13 +23,16 @@ signing up for a Google account.
 """
 
 __license__ = "GPLv3"
-__version__ = "1.8.1"
+__version__ = "2.1.0"
 __author__ = __maintainer__ = "Wolfgang Popp"
 __email__ = "mail@wolfgang-popp.de"
 
-from pathlib import Path
 import gettext
 import sys
+from pathlib import Path
+from ytcc.database import Database, MappedVideo, Video, MappedPlaylist, Playlist
+from ytcc.core import Ytcc
+from ytcc.exceptions import *
 
 
 def _get_translations_path() -> str:
