@@ -1,5 +1,5 @@
 # ytcc - The YouTube channel checker
-# Copyright (C) 2019  Wolfgang Popp
+# Copyright (C) 2020  Wolfgang Popp
 #
 # This file is part of ytcc.
 #
@@ -18,20 +18,21 @@
 
 """Exceptions in their own module to avoid circular imports."""
 
+
 class YtccException(Exception):
     """A general parent class of all Exceptions that are used in Ytcc."""
 
 
 class BadURLException(YtccException):
-    """Raised when a given URL does not refer to a YouTube channel."""
+    """Raised when a given URL cannot be handled by youtube-dl."""
 
 
-class DuplicateChannelException(YtccException):
-    """Raised when trying to subscribe to a channel the second (or more) time."""
+class NameConflictError(YtccException):
+    """Raised when trying to subscribe to a playlist the second (or more) time."""
 
 
-class ChannelDoesNotExistException(YtccException):
-    """Raised when the url of a given channel does not exist."""
+class PlaylistDoesNotExistException(YtccException):
+    """Raised when the url of a given playlist does not exist."""
 
 
 class InvalidSubscriptionFileError(YtccException):
@@ -40,3 +41,7 @@ class InvalidSubscriptionFileError(YtccException):
 
 class BadConfigException(YtccException):
     """Raised when error in config file is encountered."""
+
+
+class IncompatibleDatabaseVersion(YtccException):
+    """Raised when the database has an incompatible version."""
